File rateshift.hpp — sudio documentation

# File rateshift.hpp

↰ Parent directory (`sudio\rateshift\inc`)

## Definition (`sudio\rateshift\inc\rateshift.hpp`)

- Program Listing for File rateshift.hpp

## Includes

- `cstddef`

- `functional`

- `samplerate.h`

- `vector`

## Namespaces

- Namespace rateshift

## Classes

- Class CallbackResampler

- Class Resampler

## Enums

- Enum ConverterType

## Functions

- Function rateshift::resample